@@ -15,13 +15,14 @@ GSIF.env <- function(
     wps.server = "http://wps.worldgrids.org",
     ref_CRS = "+proj=longlat +datum=WGS84",
     NAflag = -99999,
-    license_url = "http://creativecommons.org/licenses/by/3.0/",
+    license_url = "https://creativecommons.org/licenses/by-sa/4.0/",
     project_url = "http://gsif.r-forge.r-project.org/",
+    sldepths = c(0, 5, 15, 30, 60, 100, 200),
     stdepths = c(-2.5, -10, -22.5, -45, -80, -150)/100,
     stsize = c(5, 10, 15, 30, 40, 100)/100,
     cellsize = rev(c(6/120, 3/120, 1/120, 1/240, 1/600, 1/1200, 1/3600)),
-    REST.server = 'http://rest.soilgrids.org/',
-    attributes = c("ORCDRC","PHIHOX","SNDPPT","SLTPPT","CLYPPT","CFRVOL","CEC","BLD","TAXGWRB","TAXOUSDA"),
+    REST.server = 'https://rest.soilgrids.org/',
+    attributes = c("ORCDRC","PHIHOX","SNDPPT","SLTPPT","CLYPPT","CFRVOL","CECSOL","BLDFIE","TAXNWRB","TAXOUSDA"),
     TimeSpan = list(begin=as.POSIXct("1950-01-01"), end=as.POSIXct("2005-12-30")),
     show.env = TRUE
     ){
